==> 0.0.9.tar.gz: lib/utils/ifps_dialog_utils.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:vone_ipfs/bean/select_folder_entity.dart';
import 'package:vone_ipfs/bean/upload_result_entity.dart';
import 'package:vone_ipfs/component/file_select_view.dart';
import 'package:vone_ipfs/component/file_upload_view.dart';
import 'package:vone_ipfs/utils/ipfs_utils.dart';
import 'package:vone_ipfs/component/select_directory_view.dart';

class IPFSDialog {
  ///图片上传
  static void showImageUpload(BuildContext context, double width, double height,String dirId,String dirName,
      UploadMode uploadMode,IPFSFileType fileType, ValueChanged<List<UploadResultEntity>> callback) {
    showModalBottomSheet(
        context: context,
        backgroundColor: Colors.transparent,
        isScrollControlled: true,
        builder: (BuildContext context) {
          return FileSelectView(
            dirId:dirId,
            fileType:fileType,
            dirName:dirName,
            uploadType: UploadType.TYPE_IMAGE,
            uploadMode: uploadMode,
            callback: callback,
          );
        });
  }
  ///文件选择
  static void showFileUpload(BuildContext context,String dirId,String dirName,IPFSFileType fileType,
      ValueChanged<List<UploadResultEntity>> callback) {
    showModalBottomSheet(
        context: context,
        backgroundColor: Colors.transparent,
        isScrollControlled: true,
        builder: (BuildContext context) {
          return FileSelectView(
            dirId:dirId,
            fileType: fileType,
            dirName:dirName,
            uploadType: UploadType.TYPE_FILE,
            callback: callback,
          );
        });
  }


  static void showSelectDirDialog(
      BuildContext context,String dirId, ValueChanged<SelectFolderEntity> callback) {
    showModalBottomSheet(
        context: context,
        enableDrag: false,
        backgroundColor: Colors.transparent,
        isScrollControlled: true,
        builder: (BuildContext context) {
          return SelectDirView(dirId,callback);
        });
  }
}

==> 0.0.22.tar.gz: lib/utils/ifps_dialog_utils.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:vone_ipfs/bean/select_folder_entity.dart';
import 'package:vone_ipfs/bean/upload_result_entity.dart';
import 'package:vone_ipfs/component/file_select_view.dart';
import 'package:vone_ipfs/component/file_upload_view.dart';
import 'package:vone_ipfs/utils/ipfs_utils.dart';
import 'package:vone_ipfs/component/select_directory_view.dart';

class IPFSDialog {
  ///图片上传
  static void showImageUpload(BuildContext context, double width, double height,String dirId,String dirName,
      UploadMode uploadMode,IPFSFileType fileType, ValueChanged<List<UploadResultEntity>> callback) {
    showModalBottomSheet(
        context: context,
        backgroundColor: Colors.transparent,
        isScrollControlled: true,
        builder: (BuildContext context) {
          return FileSelectView(
            dirId:dirId,
            fileType:fileType,
            dirName:dirName,
            uploadType: UploadType.TYPE_IMAGE,
            uploadMode: uploadMode,
            callback: callback,
          );
        });
  }
  ///文件选择
  static void showFileUpload(BuildContext context,String dirId,String dirName,IPFSFileType fileType,
      ValueChanged<List<UploadResultEntity>> callback,List<String>? allowedExtensions) {
    showModalBottomSheet(
        context: context,
        backgroundColor: Colors.transparent,
        isScrollControlled: true,
        builder: (BuildContext context) {
          return FileSelectView(
            dirId:dirId,
            fileType: fileType,
            dirName:dirName,
            uploadType: UploadType.TYPE_FILE,
            callback: callback,
            allowedExtensions: allowedExtensions,
          );
        });
  }


  static void showSelectDirDialog(
      BuildContext context,String dirId, ValueChanged<SelectFolderEntity> callback) {
    showModalBottomSheet(
        context: context,
        enableDrag: false,
        backgroundColor: Colors.transparent,
        isScrollControlled: true,
        builder: (BuildContext context) {
          return SelectDirView(dirId,callback);
        });
  }
}
